//
//  MXChatConfig.h
//  ChatSDK
//
//  Copyright © 2016 moxtra. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "MXChatSDKDeprecationMacros.h"
NS_ASSUME_NONNULL_BEGIN

@class MXChat;
@class MXMeet;
@class MXUserItem;
@class MXFileItem;
@class MXAddFileEntry;
@class MXTransactionData;

/**
 MXChatInputPanelLayout
 
 - MXChatInputPanelLayoutDefault: Default type with: [File Button] [Text Input] [Voice Message Button]
 - MXChatInputPanelLayoutClassic: Classic type with:  [Voice Message Button] [Text Input] [File Button]
 */
typedef NS_ENUM(NSUInteger, MXChatInputPanelLayout) {
    /*Public*/
    MXChatInputPanelLayoutDefault = 0,
    MXChatInputPanelLayoutClassic
};

/**
 MXAnnotationTool

 - MXAnnotationToolNone: Disble all annotation tool
 - MXAnnotationToolAll: Enable all annotation tool
 */
typedef NS_OPTIONS(NSUInteger, MXAnnotationTool)
{
    MXAnnotationToolNone              = 0,
    MXAnnotationToolPen               = 1 << 1,
    MXAnnotationToolText              = 1 << 2,
    MXAnnotationToolRectangle         = 1 << 3,
    MXAnnotationToolArrow             = 1 << 4,
    MXAnnotationToolEraser            = 1 << 5,
    MXAnnotationToolHighlightPen      = 1 << 6,
    MXAnnotationToolSpeechBubbles     = 1 << 7,
    MXAnnotationToolImage             = 1 << 8,
    MXAnnotationToolOval              = 1 << 9,
    MXAnnotationToolLine              = 1 << 10,
    MXAnnotationToolSelectTool        = 1 << 11,
    MXAnnotationToolAll               = 0xffffffff
};

/**
 An MXChatConfig class defines behavious in chats, and custom actions when interacting with chat views.
 */
@interface MXChatConfig : NSObject

/**
  A boolean value indicating whether the voice message is enabled. The default value is YES. Once sets to NO, the voice button on input panel will be hidden.
 */
@property (nonatomic, assign, getter=isVoiceMessageEnabled) BOOL voiceMessageEnabled;

/**
   A boolean value indicating whether add file is enabled. The default value is YES. Once sets to NO, the file button on input panel will be hidden.
 */
@property (nonatomic, assign, getter=isAddFileEnabled) BOOL addFileEnabled;

/**
 A boolean value to config whether to show or hide emoji button on input panel.Default is NO.
 */
@property (nonatomic, assign, getter=isEmojiEnabled) BOOL emojiEnabled;

/**
 A boolean value indicating whether e-sign feature is enabled. The default is YES.
 */
@property (nonatomic, assign, getter=isESignEnalbed) BOOL eSignEnabled;

/**
 A boolean value to enable/disable display read receipt. Default is NO.
 */
@property (nonatomic, assign, getter=isReadReceiptEnabled) BOOL readReceiptEnabled;

/**
 A boolean value indicating whether the parent guard feature is enabled. The default value is YES. 17 years old warings dialog will pop up in some case if parent guard is enabled.
 */
@property (nonatomic, assign, getter=isParentGuardEnabled) BOOL parentGuardEnabled;

/**
 A boolean value indicating whether importing other chats to a chat is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isImportOtherChatEnabled) BOOL importOtherChatEnabled;

/**
 A boolean value indicating whether should show the chat creation feed. The default value is YES.
 */
@property (nonatomic, assign, getter=isChatCreationFeedEnabled) BOOL chatCreationFeedEnabled;

/**
 A boolean value indicating whether saving images to album is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isSaveToAlbumEnabled) BOOL saveToAlbumEnabled;

/**
 A boolean value indicating whether sharing file  is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isShareFileEnabled) BOOL shareFileEnabled;

/**
 A boolean value indicating whether multi-tabs in chats is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isMultiTabsEnabled) BOOL multiTabsEnabled;

/**
 A boolean value indicating whether share location is enabled in chat. The default value is NO.
 */
@property (nonatomic, assign, getter=isLocationEnabled) BOOL locationEnabled;

/**
 A boolean value indicating whether annotation enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isAnnotationEnabled) BOOL annotationEnabled;

/**
 A boolean value indicating whether message feed menu is enabled.The default value is YES.
 */
@property (nonatomic, assign, getter=isMessageFeedMenuEnabled) BOOL messageFeedMenuEnabled;

/**
 A boolean value indicating whether page position comment feature is enabled.The default value is YES.
 */
@property (nonatomic, assign, getter=isPositionCommentEnabled) BOOL positionCommentEnabled;

/**
 A boolean value indicating whether book mark feature is enabled.The default value is NO.
 */
@property (nonatomic, assign) BOOL bookMarkEnabled;

/**
 A float value indicating that during this time, the message can be modified. Unit is second，default is 1800.
 @discussion If set to '-1', means the message can always be modified. '0' means can not be modified.
 */
@property (nonatomic, assign) CGFloat modifyExpireTime;

/**
 A float value indicating that during this time, the message can be deleted. Unit is second，default is 1800.
 @discussion If set to '-1', means the file can always be deleted. '0' means can not be deleted.
 */
@property (nonatomic, assign) CGFloat deleteExpireTime;

/**
 A float value indicating that during this time, the file can be deleted. Unit is second，default is -1.
 @discussion If set to '-1', means the file can always be deleted. '0' means can not be deleted.
 */
@property (nonatomic, assign) CGFloat fileDeleteExpireTime;

/**
 An UIColor value indicating chat view's background color.
 */
@property (nonatomic, strong) UIColor *chatBackgroundColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.chatBackgroundColor");

/**
 An UIColor value indicating chat actor's name color.
 */
@property (nonatomic, strong) UIColor *chatActorNameTextColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.chatActorNameTextColor");

/**
 An UIColor value indicating an incoming chat bubble's background color.
 */
@property (nonatomic, strong) UIColor *incomingChatMessageBackgroundColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.incomingChatMessageBackgroundColor");

/**
 An UIColor value indicating an incoming chat bubble's text color.
 */
@property (nonatomic, strong) UIColor *incomingChatMessageTextColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.incomingChatMessageTextColor");

/**
 An UIColor value indicating an outgoing chat bubble's background color.
 */
@property (nonatomic, strong) UIColor *outgoingChatMessageBackgroundColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.outgoingChatMessageBackgroundColor");

/**
 An UIColor value indicating an outgoing chat bubble's text color.
 */
@property (nonatomic, strong) UIColor *outgoingChatMessageTextColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.outgoingChatMessageTextColor");

/**
 An UIColor value indicating system message text color, such as: XXX joined/XXX deleted file and the time stamp in the chat.
 */
@property (nonatomic, strong) UIColor *systemMessageTextColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.2", "MXChatAppearance.systemMessageTextColor");

/**
 An enum value to config input panel's display type.Default is MXChatInputPanelLayoutDefault, please see more in MXChatInputPanelLayout.
 */
@property (nonatomic, assign) MXChatInputPanelLayout inputPanelLayout;

/**
 The extra file panel entries, set this to add more import button when user click the “+” button in input panel, see more in MXAddFileEntry.
 @discussion This config only works in chat.
 */
@property (nonatomic, strong) NSArray<MXAddFileEntry *> *extraAddFileEntries;

/**
 Annotation tools configuration, to config custom tools in file annotation. Default is MXAnnotationToolAll.
 @discussion You can choose to hide a specific tool, e.g. chatCofig.annotaion ^= MXAnnotationToolImage
 */
@property (nonatomic, assign) MXAnnotationTool annotationTools;

/**
 Called when the share button of a file option menu is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapShareButton)(MXChat *chat, UIViewController *viewController, id sender, NSURL *shareLink, NSURL *downloadLink);

/**
 Called when avatars of members are tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapMemberAvatar)(MXChat *chat, UIViewController *viewController,  id __nullable sender, MXUserItem *userItem);

/**
 Called when avatars of members are long pressed.
 */
@property (nonatomic, copy, nullable) void (^didLongPressMemberAvatar)(MXChat *chat, UIViewController *viewController, id sender, MXUserItem *userItem);

/**
 Called when the add files button is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapAddFilesButton)(MXChat *chat, UIViewController *viewController, id sender);

/**
 Called when the more files button is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapMoreFilesButton)(MXChat *chat,  UIViewController *viewController, id sender);

/**
 Called when the join meet button in feed is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapJoinMeetButtonInFeed)(MXChat *chat, NSString *meetId, UIViewController *viewController, id sender);

/**
 Called when the missed call button is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapMissedCallButton)(MXChat *chat, MXUserItem *caller, UIViewController *viewController, id sender);

/**
 Called when the transaction button is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapTransactionButton)(MXChat *chat, MXTransactionData *data, id sender);

/**
 Called when some files have been copied to another chat.
 */
@property (nonatomic, copy, nullable) void (^didCopyFilesHandler)(MXChat *fromChat, MXChat *toChat, UIViewController *viewController, NSArray<MXFileItem *> *files);

/**
 Called when some files have been moved to another chat.
 */
@property (nonatomic, copy, nullable) void (^didMoveFilesHandler)(MXChat *fromChat, MXChat *toChat, UIViewController *viewController, NSArray<MXFileItem *> *files);

/**
 Called when some actions need 2FA. Set this block object to enable 2FA.
 @discussion Once completed the authentication, please call 'completionHandler' immediately to feedback the authentication result. Only 'YES' will trigger the action.
 */
@property (nonatomic, copy, nullable) void (^chat2FAHandler)(void(^completionHandler)(BOOL pass));


/**
 When send a new message, SDK calls this block to get a modified message. You can use this block to modify original messages before they are sended.
 */
@property (nonatomic, copy, nullable) NSString * (^chatMessageModifyHandler)(MXChat *chat, UIViewController *viewController, NSString *originalMessage);

@end

NS_ASSUME_NONNULL_END
