//
//  MXFileItem.h
//  ChatSDK
//
//  Copyright © 2017 moxtra. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@class MXFolderItem;

/**
 The MXFileItem class provides interfaces for basic information about files and fetching thumbnail images.
 */
@interface MXFileItem : NSObject

/**
 File name.
 */
@property (nonatomic, strong, readonly) NSString *name;

/**
 Last updated time.
 */
@property (nonatomic, strong, readonly) NSDate *updatedTime;

/**
 Created time.
 */
@property (nonatomic, strong, readonly) NSDate *createdTime;

/**
 The folder object in which this file is located in. Nil if this is a root file.
 */
@property (nonatomic, strong, readonly, nullable) MXFolderItem *folder;

/**
 The chat that this file belongs to.
 */
@property (nonatomic, strong, readonly) MXChat *chat;

/**
 Fetch thumbnail of this file.
 
 @param complete A block object to be executed when the action completes
 */
- (void)fetchThumbnailWithCompletionHandler:(void (^ _Nullable)(NSError * _Nullable errorOrNil, NSString * _Nullable localPathOrNil))complete;

@end

NS_ASSUME_NONNULL_END
