//
//  MXMeetConfig.h
//
//  Copyright (c) Moxtra Inc. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@class MXMeet;
@class MXUserItem;


/**
 The MXMeetConfig class defines behaviours of meet sessions.
 */
@interface MXMeetConfig : NSObject

/**
 A boolean value indicating whether PushKit is enabled. The default value is NO.
 @discussion Set this to YES to allow CallKit support.
 */
@property (nonatomic, assign, getter=isPushKitEnabled) BOOL pushKitEnabled;

/**
 A boolean value indicating whether developer is using CallKit by self. The default value is NO.
 @discussion Set this to YES to tell SDK that you are using CallKit.
 */
@property (nonatomic, assign, getter=isUsingCallKit) BOOL usingCallKit;

/**
 A boolean value indicating whether add file is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isAddFileEnabled) BOOL addFileEnabled;

/**
 A boolean value indicating whether chat is enabled in meet. The default value is YES.
 */
@property (nonatomic, assign, getter=isChatEnabled) BOOL chatEnabled;

/**
 A boolean value indicating whether telephony is enabled in meetings. The default value is YES.
 */
@property (nonatomic, assign, getter=isTelephonyEnabled) BOOL telephonyEnabled;

/**
 A boolean value indicating whether VoIP is enabled in meetings. The default value is YES.
 */
@property (nonatomic, assign, getter=isVoIPEnabled) BOOL VoIPEnabled;

/**
 A boolean value indicating whether video is enabled in meetings. The default value is YES.
 */
@property (nonatomic, assign, getter=isVideoEnabled) BOOL videoEnabled;

/**
 A boolean value indicating whether annotation enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isAnnotationEnabled) BOOL annotationEnabled;

/**
 A boolean value indicating whether video should start automatically. The default value is NO.
 */
@property (nonatomic, assign, getter=isAutoStartVideo) BOOL autoStartVideo;

/**
 A boolean value indicating whether the meet id is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isMeetIdEnabled) BOOL meetIdEnabled;

/**
 A boolean value indicating whether the meet link is enabled. The default value is YES.
 */
@property (nonatomic, assign, getter=isMeetLinkEnabled) BOOL meetLinkEnabled;

/**
 A boolean value indicating whether joins VoIP automatically. The default value is NO.
 */
@property (nonatomic, assign, getter=isAutoJoinVoIP) BOOL autoJoinVoIP;

/**
 A boolean value indicating whether attendees are muted automatically when they joined meetings. The default value is NO.
 */
@property (nonatomic, assign, getter=isAutoMuteAfterJoined) BOOL autoMuteAfterJoined;

/**
 A boolean value indicating whether recording is enabled in meetings. The default value is YES.
 */
@property (nonatomic, assign, getter=isRecordingEnabled) BOOL recordingEnabled;

/**
 A boolean value indicating whether recording should start automatically. The default value is NO.
 */
@property (nonatomic, assign, getter=isAutoRecording) BOOL autoRecording;

/**
 A boolean value indicating whether UI elements about invitation are available so that user can invite participant. The default value is YES.
 */
@property (nonatomic, assign, getter=isInviteParticipantEnabled) BOOL inviteParticipantEnabled;

/**
 A boolean value indicating whether attendees can unmute by themselves. The default value is YES.
 */
@property (nonatomic, assign, getter=isUnmuteByAttendeeSelfEnabled) BOOL unmuteByAttendeeSelfEnabled;

/**
 A boolean value indicating whether attendees can be unmuted by the host. The default value is NO.
 */
@property (nonatomic, assign, getter=isUnmuteByHostEnabled) BOOL unmuteByHostEnabled;

/**
 A boolean value indicating whether attendees can bu unmuted by the presenter. The default value is NO.
 */
@property (nonatomic, assign, getter=isUnmuteByPresenterEnabled) BOOL unmuteByPresenterEnabled;

/**
 A boolean value indicating whether attendees can activate camera. The default value is YES.
 */
@property (nonatomic, assign, getter=isActivateCameraByAttendeeSelfEnabled) BOOL activateCameraByAttendeeSelfEnabled;

/**
 A boolean value indicating whether the host can save files at the end of meetings. The default value is YES.
 */
@property (nonatomic, assign, getter=isSaveMeetingFilesEnabled) BOOL saveMeetingFilesEnabled;

/**
 A boolean value indicating whether clipping screen in meetings is allowed. The default value is YES.
 */
@property (nonatomic, assign, getter=isClipMeetingScreenEnabled) BOOL clipMeetingScreenEnabled;

/**
 A boolean value indicating whether the button used to minimize meeting view is Hidden. The default value is NO.
 */
@property (nonatomic, assign, getter=isMinimizeViewHidden) BOOL minimizeViewHidden;

/**
 A boolean value indicating whether proximity monitoring is enabled in meetings. The default value is YES.
 */
@property (nonatomic, assign, getter=isProximityMonitoringEnabled) BOOL proximityMonitoringEnabled;

/**
 Meeting View main tone color. The default value is RGB(153.0f, 153.0f, 153.0f).
 */
@property (nonatomic, copy, nullable) UIColor *meetViewBackgroundColor MX_DEPRECATED_WILL_BE_REMOVED_IN_PLEASE_USE("5.1", "MXMeetAppearance.meetViewBackgroundColor");

/**
 A boolean value indicating whether share location is enabled in meet. The default value is NO.
 */
@property (nonatomic, assign, getter=isLocationEnabled) BOOL locationEnabled;

/**
 The audio button of meet panel.
 */
@property (nonatomic, strong, readwrite) UIButton *audioButton;

/**
 The speaker button of meet panel.
 */
@property (nonatomic, strong, readwrite) UIButton *speakerButton;

/**
 The extra file panel entries, set this to add more import button when user click the “+” button in input panel, see more in MXAddFileEntry.
 @discussion This config only works in meet
 */
@property (nonatomic, strong, nullable) NSArray<MXAddFileEntry *> *extraAddFileEntries;

/**
 Called when the more files button is tapped.
 */
@property (nonatomic, copy, nullable) void (^didTapMoreFilesButton)(MXMeet *meet,  UIViewController *viewController, id sender);

@end

NS_ASSUME_NONNULL_END
