//
//  MXUserItem.h
//  ChatSDK
//
//  Copyright (c) Moxtra Inc. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

/**
 The MXUserItem class provides interfaces for basic information about users as well as some lightweight operations.
 */
@interface MXUserItem : NSObject

/**
 Org id of this user.
 */
@property (nonatomic, strong, readonly, nullable)NSString *orgId;

/**
 Unique id of this user.
 */
@property (nonatomic, strong, readonly) NSString *uniqueId;

/**
 Firstname of this user.
 */
@property (nonatomic, strong, readonly, nullable) NSString *firstname;

/**
 Lastname of this user.
 */
@property (nonatomic, strong, readonly, nullable) NSString *lastname;

/**
 Email of this user.
 */
@property (nonatomic, strong, readonly, nullable) NSString *email;

/**
 Title of this user.
 */
@property (nonatomic, strong, readonly, nullable) NSString *title;

/**
 If this user item is the current user
 */
@property (nonatomic, assign, readonly) BOOL isMyself;

/**
 Fetch the user's avatar
 
 @param completionHandler A block object to be executed when the action completes
 */
- (void)fetchAvatarWithCompletionHandler:(void (^ _Nullable)(NSError * _Nullable errorOrNil, NSString * _Nullable localPath))completionHandler;

@end

NS_ASSUME_NONNULL_END
