//
//  MXUserListModel.h
//  ChatSDK
//
//  Created by Moxtra on 2017/3/10.
//  Copyright © 2017年 moxtra. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@class MXUserListModel;
@class MXUserItem;
@class MXTeamItem;

/**
 The MXUserListModelDelegate protocol describes the methods that MXUserListModel objects call on their delegates to handle user list events
 */
@protocol MXUserListModelDelegate <NSObject>

@optional
/**
 Tells the delegate that some users have been created
 
 @param userListModel The related user list model
 @param createdUsers  An array containing created users
 */
- (void)userListModel:(MXUserListModel *)userListModel didCreateUsers:(NSArray<MXUserItem *> *)createdUsers;

/**
 Tells the delegate that some users have been updated
 
 @param userListModel The related user list model
 @param updatedUsers  An array containing updated users
 */
- (void)userListModel:(MXUserListModel *)userListModel didUpdateUsers:(NSArray<MXUserItem *> *)updatedUsers;

/**
 Tells the delegate that some users have been deleted
 
 @param userListModel The related user list model
 @param deletedUsers  An array containing deleted users
 */
- (void)userListModel:(MXUserListModel *)userListModel didDeleteUsers:(NSArray<MXUserItem *> *)deletedUsers;

/**
 Tells the delegate that some teams have been created
 
 @param userListModel The related user list model
 @param createdTeams  An array containing created teams
 */
- (void)userListModel:(MXUserListModel *)userListModel didCreatedTeams:(NSArray<MXTeamItem *> *)createdTeams;

/**
 Tells the delegate that some teams have been updated
 
 @param userListModel The related user list model
 @param updatedTeams  An array containing updated teams
 */
- (void)userListModel:(MXUserListModel *)userListModel didUpdateTeams:(NSArray<MXTeamItem *> *)updatedTeams;

/**
 Tells the delegate that some teams have been deleted
 
 @param userListModel The related user list model
 @param deletedTeams  An array containing deleted teams
 */
- (void)userListModel:(MXUserListModel *)userListModel didDeleteTeams:(NSArray<MXTeamItem *> *)deletedTeams;

@end


/**
 The MXUserListModel class provides interfaces for getting all users and teams related with the current user, and getting shared chats with them.
 */
@interface MXUserListModel : NSObject

/**
 The object that acts as delegate of the user list
 */
@property (nonatomic, weak, nullable) id<MXUserListModelDelegate> delegate;

/**
 Return an array containing all users
 */
- (NSArray<MXUserItem *> *)users;

/**
 Return an array containing all teams
 */
- (NSArray<MXTeamItem *> *)teams;

/**
 Get all chats shared with a specified user.
 
 @param user The specified user.
 @param completion Called this block after request finished. Get an array of MXChat object if request succeed, otherwise will get an error
 */
- (void)fetchSharedChatsWithUser:(nonnull MXUserItem *)user completion:(void (^__nullable)(NSError *__nullable errorOrNil, NSArray<MXChat *> *__nullable chats))completion;
@end

NS_ASSUME_NONNULL_END
